module Translator
	
	VERBOSE = false
	PARANOIA = true
	ENDL = "\r\n"
	
	#tag for parsing an option file
	TAG_OPTION = 'option'
	TAG_STATE = 'state'
	TAG_SBB = 'subsequent-basic-behavior'
	TAG_SP = 'set-parameter'
	TAG_SEOS = 'set-enumerated-output-symbol'
	TAG_SDOS = 'set-decimal-output-symbol'
	TAG_SBOS = 'set-boolean-output-symbol'
	TAG_SO = 'subsequent-option'
	TAG_DT = 'decision-tree'
	TAG_OPR = 'option-parameter-ref'
	TAG_DV = 'decimal-value'
	TAG_BV = 'boolean-value'
	TAG_IF = 'if'
	TAG_ELSE = 'else'
	TAG_COND = 'condition'
	TAG_TTS = 'transition-to-state'
	TAG_GT = 'greater-than'
	TAG_LT = 'less-than'
	TAG_GTEQ = 'greater-than-or-equal-to'
	TAG_LTEQ = 'less-than-or-equal-to'
	TAG_EQ = 'equal-to'
	TAG_NEQ = 'not-equal-to'
	TAG_PLUS = 'plus'
	TAG_MINUS = 'minus'
	TAG_DISR = 'decimal-input-symbol-ref'
	TAG_BISR = 'boolean-input-symbol-ref'
	TAG_EISR = 'enumerated-input-symbol-ref'
	TAG_DOSR = 'decimal-output-symbol-ref'
	TAG_BOSR = 'boolean-output-symbol-ref'
	TAG_EOSR = 'enumerated-output-symbol-ref'
	TAG_AND = 'and'
	TAG_OR = 'or'
	TAG_WP = 'with-parameter'
	TAG_EISC = 'enumerated-input-symbol-comparison'
	TAG_CDT = 'common-decision-tree'
	TAG_COMMON_ACTION = 'common-action'
	TAG_CR = 'constant-ref'
	TAG_TOSX = 'time-of-state-execution'
	TAG_TOOX = 'time-of-option-execution'
	TAG_NOT = 'not'
	TAG_SORTS = 'subsequent-option-reached-target-state'
	TAG_CONFLICT = 'conflict'
	TAG_MPL = 'multiply'
	TAG_DIV = 'divide'
	TAG_MOD = 'mod'
	TAG_CE = 'conditional-expression'
	TAG_EX1 = 'expression1'
	TAG_EX2 = 'expression2'
	TAG_EV = 'enum-element-ref'
	
	#tags for parsing an option-defintions file
	TAG_ODS = 'option-definitions'
	TAG_OD = 'option-definition'
	TAG_DPARA = 'decimal-parameter'
	TAG_BPARA = 'boolean-parameter'
	TAG_EPARA = 'enumerated-parameter'

	#tags for symbol files
	TAG_BASIC_BEHAVIORS = 'basic-behaviors'
	TAG_SYMBOLS = 'symbols'
	TAG_DIS = 'decimal-input-symbol'
	TAG_DOS = 'decimal-output-symbol'
	TAG_E = 'enumeration'
	TAG_ENUM = 'enum-element'
	TAG_EIS = 'enumerated-input-symbol'
	TAG_EOS = 'enumerated-output-symbol'
	TAG_BIS = 'boolean-input-symbol'
	TAG_BOS = 'boolean-output-symbol'
	TAG_CONST = 'constant'
	TAG_BBS = 'basic-behaviors'
	TAG_BB = 'basic-behavior'

	#Tags for agent files
	TAG_AGENT_COLLECTION = 'agent-collection'
	TAG_AGENT = 'agent'
	TAG_TITLE = 'title'
	TAG_SOFTWARE_ENVIRONMENT = 'software-environment'
	TAG_PLATFORM = 'platform'
	TAG_OPTIONS = 'options'
	TAG_XINCLUDE = 'xi:include'

	#tokens for parsing a xtc file
	TOKEN_TRUE = 'true'
	TOKEN_FALSE = 'false'
	TOKEN_OPTION = 'option'
	TOKEN_INITIAL = 'initial'
	TOKEN_TARGET = 'target'
	TOKEN_STATE = 'state'
	TOKEN_COMMON = 'common'
	TOKEN_DECISION = 'decision'
	TOKEN_ACTION = 'action'
	TOKEN_STAY = 'stay'
	TOKEN_TTS = 'goto'
	TOKEN_IF = 'if'
	TOKEN_ELSE = 'else'
	TOKEN_TOSX = 'state_time'
	TOKEN_TOOX = 'option_time'
	TOKEN_SORTS = 'action_done'
	TOKEN_AGENT = 'agent'
	TOKEN_FUNCTION = 'function'
	TOKEN_ENUM = 'enum'
	TOKEN_INPUT = 'input'
	TOKEN_OUTPUT = 'output'
	TOKEN_BOOL = 'bool'
	TOKEN_FLOAT = 'float'
	TOKEN_CONST = 'const'
	TOKEN_NAMESPACE = 'namespace'
	TOKEN_BEHAVIOR = 'behavior'
	TOKEN_INCLUDE = 'include'
	TOKEN_INTERNAL = 'internal'
	TOKEN_CAPACITY = 'capacity'
	TOKEN_SYNCHRONIZED = 'synchronized'
	TOKEN_CONFLICT = 'conflict'
	
	#Attributes
	ATTR_NAME = 'name'
	ATTR_MEASURE = 'measure'
	ATTR_RANGE = 'range'
	ATTR_DESCRIPTION = 'description'
	ATTR_REF = 'ref'
	ATTR_VALUE = 'value'
	ATTR_IS_TARGET_STATE = 'is-target-state'
	ATTR_INITIAL_STATE = 'initial-state'
	ATTR_TITLE = 'title'
	ATTR_ID = 'id'
	ATTR_ROOT_OPTION = 'root-option'
	ATTR_ENUM = 'enumeration'
	ATTR_INTERNAL = 'internal'
	ATTR_CAPACITY = 'capacity'
	ATTR_SYNCHRONIZED = 'synchronized'
	
	ATTR_XMLNS = 'xmlns'
	ATTR_XMLNS_XSI = 'xmlns:xsi'
	ATTR_XSI_SCHEMALOCATION = 'xsi:schemaLocation'
	ATTR_XMLNS_XI = 'xmlns:xi'
	ATTR_HREF = 'href'
	
	#filenames
	OPTION_DEFINITIONS_FILE = 'options.xml'
	OPTION_DEFINITIONS_ENTITY = 'options'
	DTD_INCLUDE_FILE = 'symbol-and-basic-behavior-files.dtd'
	DTD_INCLUDE_ENTITY = 'symbol-and-basic-behavior-files'
	AGENT_COLLECTION_FILE = 'agents.xml'
	TIMESTAMP_FILE = File.join(File.expand_path(File.dirname(__FILE__)), 'timestamp')
end
